# shtomo
a good friend with reverse/bind shell

```
usage: shtomo.py [-h] ip port

positional arguments:
  ip          target ip
  port

options:
  -h, --help  show this help message and exit
```

connection to a shell and press ctrl+c and try some internal cmdlet

> use term command in internal shell for a full functional shell
> 
> and ctrl-D for exit